@@ -1,25 +1,7 @@
-### $Id: VarCorr.R,v 1.2 2001/01/10 19:04:03 bates Exp $
-###
 ###          Extract variance components of lme models.
 ###
-### Copyright 1997-2001  Jose C. Pinheiro <jcp@research.bell-labs.com>,
+### Copyright 1997-2003  Jose C. Pinheiro <Jose.Pinheiro@pharma.novartis.com>,
 ###                      Douglas M. Bates <bates@stat.wisc.edu>
-###
-### This file is part of the nlme library for S and related languages.
-### It is made available under the terms of the GNU General Public
-### License, version 2, or at your option, any later version,
-### incorporated herein by reference.
-###
-### This program is distributed in the hope that it will be
-### useful, but WITHOUT ANY WARRANTY; without even the implied
-### warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-### PURPOSE.  See the GNU General Public License for more
-### details.
-###
-### You should have received a copy of the GNU General Public
-### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
 
 VarCorr <- function( x, sigma = 1, rdig = 3) UseMethod("VarCorr")
 
@@ -64,7 +46,7 @@ VarCorr.lme <- function( x, sigma = 1., rdig = 3)
   rownames <- rep("", sum(nrows) + Q)
   rownames[trows] <- paste( names( m ), "=" )
   rr <- 1
-  for (i in seq( along = m ) ) {
+  for (i in seq_along( m ) ) {
     rownames[ rr + (1:nrows[i]) ] <- dimnames( m[[i]] )[[1]]
     if (!is.null( corr[[i]] )) {
       v[ rr + (1:nrows[i]), 2 + (1:ncol(corr[[i]])) ] <- corr[[i]]
@@ -100,11 +82,11 @@ VarCorr.pdMat <- function( x, sigma = 1., rdig = 3)
     if ( inherits( attr(x, "formula"), "listForm" ) ) {# an nlme'ism
       paste(class(x)[[1]], "(list(",
             paste( sapply( attr(x, "formula"),
-                          function(x) as.character(deparse(as.vector(x)))),
+                          function(x) as.character(deparse(x))),
                   collapse=","), "))", sep = "")
     } else {
       paste(class(x)[[1]], "(",
-            substring(deparse(as.vector(attr(x, "formula"))), 2), ")", sep = "")
+            substring(deparse(attr(x, "formula")), 2), ")", sep = "")
     }
       if ( attr(sx, "noCorrelation") | (p <= 1) ) {
     return(v)
@@ -124,12 +106,13 @@ VarCorr.pdBlocked <- function( x, sigma = 1., rdig = 3)
 {
   m <- lapply( x, VarCorr, sigma = sigma, rdig = rdig)
   bd <- do.call("rbind", m)
-  corr <- lapply( m, attr, which = "corr")
-  maxCorr <- 0
-  if ( !all( Nulls <- sapply( corr, is.null ) ) ) {
-    maxCorr <- max( sapply( corr[!Nulls], ncol ) )
+## the following code does not appear to be used at all
+##   corr <- lapply( m, attr, which = "corr")
+##   maxCorr <- 0
+##   if ( !all( Nulls <- sapply( corr, is.null ) ) ) {
+##     maxCorr <- max( sapply( corr[!Nulls], ncol ) )
 
-  }
+##   }
   attr(bd, "formStr") <-
     paste( sapply( m, attr, which = "formStr" ), collapse = ", ")
   bd
